import matplotlib.pyplot as plt
from matplotlib.animation import FuncAnimation
import numpy as np
from life_game import LifeGame
from life_game import IteratorLifeGame


def trans(matrix):
    row, col = matrix.shape
    tmp = np.zeros([row, col])
    for i in range(row):
        for j in range(col):
            tmp[i, j] = matrix[row - i - 1, j]
    return tmp


class LifeGameAnimation(LifeGame):

    def __init__(self, matrix, universe_level=2, frames=20):
        super().__init__(matrix, universe_level)
        self.frames = frames
        self.iterLG = IteratorLifeGame(matrix, self.universe_level, frames)
        self.iter = self.iteruniverse()
        # self.count = 0

    def iteruniverse(self):
        for LG in self.iterLG:
            yield LG.universe

    def update(self, frame):
        matrix = next(self.iter)

        self.ax.pcolormesh(trans(matrix), cmap='Greys')
        plt.title('generation: ' + 'n=' + str('%03d' % (frame + 2)))

    def animation(self):
        fig = plt.figure(figsize=(6, 3), dpi=280)
        ax = plt.axes([0.075, 0.025, 0.85, 0.85])
        ax.set_aspect('equal', 'datalim')
        C = 10 * 2**(self.universe_level - 1)
        ax.set_xlim(0, 2 * C)
        ax.set_ylim(0, C)
        ax.xaxis.set_minor_locator(plt.MultipleLocator(1))
        ax.yaxis.set_minor_locator(plt.MultipleLocator(1))
        width = 2 / self.universe_level
        ax.grid(
            which='minor',
            axis='x',
            linewidth=width,
            linestyle='-',
            color='0.7')
        ax.grid(
            which='minor',
            axis='y',
            linewidth=width,
            linestyle='-',
            color='0.7')
        ax.tick_params(labelbottom="off", bottom="off")    # x軸の削除
        ax.tick_params(labelleft="off", left="off")    # y軸の削除
        ax.set_xticklabels([])
        ax.set_yticklabels([])
        self.ax = ax
        self.ax.pcolormesh(trans(self.universe), cmap='Greys')
        plt.title('generation: ' + 'n=' + str('%03d' % 1))
        print('initial')

        ani = FuncAnimation(
            fig, self.update, interval=600, frames=self.frames, repeat=False)
        # ani.save('anim.gif', writer="imagemagick")

        plt.show()


if __name__ == '__main__':
    G = np.zeros([4, 5], dtype='int8')
    for i in range(1, 4):
        G[1, i] = 1
    G[2, 2] = 1
    # G=[[0 0 0 0 0]
    #    [0 1 1 1 0]
    #    [0 0 1 0 0]
    #    [0 0 0 0 0]]

    LGA = LifeGameAnimation(G, 2, 20)
    LGA.animation()
