import matplotlib.pyplot as plt
import numpy as np


def trans(matrix):
    row, col = matrix.shape
    tmp = np.zeros([row, col])
    for i in range(row):
        for j in range(col):
            tmp[i, j] = matrix[row - i - 1, j]
    return tmp


def display(matrix, level):

    fig = plt.figure(figsize=(6, 3), dpi=280)
    ax = plt.axes([0.025, 0.025, 0.95, 0.95])
    ax.set_aspect('equal', 'datalim')
    C = 10 * 2**(level - 1)
    ax.set_xlim(0, 2 * C)
    ax.set_ylim(0, C)
    ax.xaxis.set_minor_locator(plt.MultipleLocator(1))
    ax.yaxis.set_minor_locator(plt.MultipleLocator(1))
    width = 2 / level
    ax.grid(
        which='minor', axis='x', linewidth=width, linestyle='-', color='0.8')
    ax.grid(
        which='minor', axis='y', linewidth=width, linestyle='-', color='0.8')
    ax.tick_params(labelbottom="off", bottom="off")    # x軸の削除
    ax.tick_params(labelleft="off", left="off")    # y軸の削除
    ax.set_xticklabels([])
    ax.set_yticklabels([])

    im, = ax.plot([], [])

    ax.pcolormesh(trans(matrix), cmap='Greys')
    plt.show()


if __name__ == '__main__':
    import life_game as lg

    G = np.zeros([4, 5], dtype='int8')
    for i in range(1, 4):
        G[1, i] = 1
    G[2, 2] = 1
    # G=[[0 0 0 0 0]
    #    [0 1 1 1 0]
    #    [0 0 1 0 0]
    #    [0 0 0 0 0]]

    iterLG = lg.IteratorLifeGame(G, 1, 18)
    for i, LG in enumerate(iterLG):
        print("generation = ", i + 1, " :")
        print(LG.universe)
        LG.display()
